// This is the main file for the Netlify Build plugin wekit-storybook.
// Please read the comments to learn more about the Netlify Build plugin syntax.
// Find more information in the Netlify documentation.

/* eslint-disable no-unused-vars */
// The plugin main logic uses `on...` event handlers that are triggered on
// each new Netlify Build.
// Anything can be done inside those event handlers.
// Information about the current build are passed as arguments. The build
// configuration file and some core utilities are also available.

import fs from 'fs/promises'
import { existsSync } from 'fs'

const isObject = (val) =>
  Object.prototype.toString.call(val) == '[object Object]'

let publishDir

export const onPreBuild = async function ({
  netlifyConfig,
  inputs,
  constants,
}) {
  const { variable, overwrites } = inputs
  publishDir = constants.PUBLISH_DIR
  const { [variable]: check = false } = process.env
  if (!check) {
    return
  }

  Object.entries(overwrites).forEach(([key, value]) => {
    const { [key]: current } = netlifyConfig.build
    if (isObject(current) && isObject(value)) {
      netlifyConfig.build[key] = { ...current, ...value }
    } else {
      netlifyConfig.build[key] = value
    }
  })
}

export const onBuild = async function ({ constants }) {
  // PUBLISH_DIR can't be changed so we move the contents to the new directory
  const bothExists = existsSync(constants.PUBLISH_DIR) && existsSync(publishDir)
  if (constants.PUBLISH_DIR !== publishDir && bothExists) {
    await fs.rename(publishDir, `${publishDir}.old`)
    await fs.rename(constants.PUBLISH_DIR, publishDir)
  }
}
